fnss.topologies.topology.Topology.add_nodes_from — FNSS 0.7.0 documentation

# fnss.topologies.topology.Topology.add_nodes_from

`Topology.` `add_nodes_from`(nodes, **attr)

  Add multiple nodes.

  Parameters: | nodes : iterable container A container of nodes (list, dict, set, etc.). OR A container of (node, attribute dict) tuples. Node attributes are updated using the attribute dict. attr : keyword arguments, optional (default= no attributes) Update attributes for all nodes in nodes. Node attributes specified in nodes as a tuple take precedence over attributes specified generally.

  See also

  `add_node`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_nodes_from('Hello')
      >>> K3 = nx.Graph([(0,1),(1,2),(2,0)])
      >>> G.add_nodes_from(K3)
      >>> sorted(G.nodes(),key=str)
      [0, 1, 2, 'H', 'e', 'l', 'o']

  Use keywords to update specific node attributes for every node.

      >>> G.add_nodes_from([1,2], size=10)
      >>> G.add_nodes_from([3,4], weight=0.4)

  Use (node, attrdict) tuples to update attributes for specific nodes.

      >>> G.add_nodes_from([(1,dict(size=11)), (2,{'color':'blue'})])
      >>> G.node[1]['size']
      11
      >>> H = nx.Graph()
      >>> H.add_nodes_from(G.nodes(data=True))
      >>> H.node[1]['size']
      11